@@ -24,7 +24,7 @@ def test_vk_user_profile_no_username():
 def test_vk_closed_user_profile():
     info = extract(parse('https://vk.com/alex')[0])
 
-    assert info.get('fullname') in ('Александр Чудаев')
+    assert info.get('fullname') in ('Александр Чудаев', 'Alexander Chudaev')
 
 
 def test_vk_blocked_user_profile():
@@ -41,6 +41,18 @@ def test_yandex_disk():
     assert info.get('name') == 'Trapl  Zdenek'
 
 
+def test_yandex_reviews():
+    info = extract(parse('https://reviews.yandex.ru/user/1a7dv00dqrdgjf6qkyn8kw37jw')[0])
+
+    assert info.get('yandex_public_id') == '1a7dv00dqrdgjf6qkyn8kw37jw'
+    assert info.get('fullname') == 'Darya Gindina'
+    assert info.get('image') == 'https://avatars.mds.yandex.net/get-yapic/59871/oLXpnRHSVknK56vRAYx2Iuya6U-1/islands-200'
+    assert info.get('is_verified') == 'False'
+    assert info.get('reviews_count') == '1'
+    assert info.get('following_count') == '0'
+    assert info.get('follower_count') == '0'
+
+
 @pytest.mark.skip(reason="failed from github CI infra IPs")
 def test_instagram():
     info = extract(parse('https://www.instagram.com/alexaimephotography/')[0])
@@ -81,9 +93,40 @@ def test_habr():
 
     assert info.get('uid') == '1371978'
     assert info.get('username') == 'm1rko'
+    assert info.get('image') == '//habrastorage.org/getpro/habr/avatars/4ec/bd0/85d/4ecbd085d692835a931d03174ff19539.png'
+
+
+def test_habr_no_image():
+    info = extract(parse('https://habr.com/ru/users/ne555/')[0])
+
+    assert info.get('uid') == '1800409'
+    assert info.get('username') == 'ne555'
+    assert not 'image' in info
+
+
+def test_twitter_shadowban_no_account():
+    info = extract(parse('https://shadowban.eu/.api/sgfrgrrr')[0])
+
+    assert info.get('has_tweets') == 'False'
+    assert info.get('is_exists') == 'False'
+    assert info.get('username') == 'sgfrgrrr'
+    assert not 'is_protected' in info
+    assert not 'has_ban' in info
+    assert not 'has_search_ban' in info
+    assert not 'has_banned_in_search_suggestions' in info
+
+def test_twitter_shadowban():
+    info = extract(parse('https://shadowban.eu/.api/trump')[0])
+
+    assert info.get('has_tweets') == 'True'
+    assert info.get('is_exists') == 'True'
+    assert info.get('username') == 'Trump'
+    assert info.get('is_protected') == 'False'
+    assert info.get('has_ban') == 'False'
+    assert info.get('has_search_ban') == 'False'
+    assert info.get('has_banned_in_search_suggestions') == 'False'
 
 
-# @pytest.mark.skip(reason="broken, https://github.com/soxoj/socid_extractor/issues/3")
 def test_twitter():
     _, headers = get_twitter_headers({})
     info = extract(parse('https://twitter.com/i/api/graphql/ZRnOhhXPwue_JGILb9TNug/UserByScreenName?variables=%7B%22screen_name%22%3A%22cardiakflatline%22%2C%22withHighlightedLabel%22%3Atrue%7D', headers=headers)[0])
@@ -95,10 +138,10 @@ def test_twitter():
     assert info.get('image') == 'https://pbs.twimg.com/profile_images/745944619213557760/vgapfpjV.jpg'
     assert info.get('image_bg') == 'https://pbs.twimg.com/profile_banners/45926816/1487198278'
     assert info.get('is_protected') == 'False'
-    assert info.get('follower_count') == '46323'
-    assert info.get('following_count') == '1469'
     assert info.get('location') == 'Los Angeles, CA'
-    assert info.get('favourites_count') == '1180'
+    assert 'follower_count' in info
+    assert 'following_count' in info
+    assert 'favourites_count' in info
 
 
 def test_reddit():
@@ -131,13 +174,26 @@ def test_facebook_group():
     assert info.get('username') == 'discord'
 
 
-def test_github():
+def test_github_html():
     info = extract(parse('https://github.com/soxoj')[0])
 
     assert info.get('uid') == '31013580'
     assert info.get('username') == 'soxoj'
 
 
+def test_github_api():
+    info = extract(parse('https://api.github.com/users/soxoj')[0])
+
+    assert info.get('uid') == '31013580'
+    assert info.get('image') == 'https://avatars.githubusercontent.com/u/31013580?v=4'
+    assert info.get('created_at') == '2017-08-14T17:03:07Z'
+    assert 'follower_count' in info
+    assert 'following_count' in info
+    assert 'public_gists_count' in info
+    assert 'public_repos_count' in info
+    assert info.get('bio') == 'dev, infosec, osint'
+    assert info.get('blog_url') == 'https://t.me/s/osint_mindset'
+
 def test_yandex_disk_photos():
     info = extract(parse('https://yadi.sk/a/oiySK_wg3Vv5p4')[0])
 
@@ -172,13 +228,34 @@ def test_my_mail_communities():
     assert info.get('isVideoChannel') == 'False'
 
 
-@pytest.mark.skip(reason="empty result, additional header needed")
 def test_yandex_music_user_profile():
-    info = extract(parse('https://music.yandex.ru/handlers/library.jsx?owner=pritisk')[0])
+    headers = {'referer': 'https://music.yandex.ru/users/pritisk/playlists'}
+    info = extract(parse('https://music.yandex.ru/handlers/library.jsx?owner=pritisk', headers=headers)[0])
 
     assert info.get('yandex_uid') == '16480689'
     assert info.get('username') == 'pritisk'
     assert info.get('name') == 'Юрий Притиск'
+    assert info.get('image') == 'https://avatars.mds.yandex.net/get-yapic/29310/gK74BTyv8LrLRT0mQFIR2xcWv8-1/islands-200'
+    assert info.get('links') == '[]'
+    assert info.get('is_verified') == 'False'
+    assert info.get('liked_albums') == '0'
+    assert info.get('liked_artists') == '0'
+
+
+@pytest.mark.skip(reason="failed from github CI infra IPs")
+def test_yandex_zen_user_profile():
+    info = extract(parse('https://zen.yandex.ru/user/uyawkukxyf60ud6hjrxr2rq130')[0])
+
+    assert info.get('yandex_public_id') == 'uyawkukxyf60ud6hjrxr2rq130'
+    assert info.get('fullname') == 'Нина Кравченко'
+    assert info.get('image') == 'https://avatars.mds.yandex.net/get-yapic/51169/DKXVQdtL3tZ5cayBXnnicLaKcE-1/islands-200'
+    assert info.get('messenger_guid') == 'e4615300-548b-9a46-73cf-527d47fe57ed'
+    assert info.get('links') == '[]'
+    assert info.get('type') == 'user'
+    assert int(info.get('comments_count')) > 20
+    assert info.get('status') == 'active'
+    assert 'following_count' in info
+    assert 'follower_count' in info
 
 
 def test_yandex_znatoki_user_profile():
@@ -199,7 +276,7 @@ def test_behance():
 
 
 def test_500px():
-    info = extract(parse('https://api.500px.com/graphql?operationName=ProfileRendererQuery&variables=%7B%22username%22%3A%22the-maksimov%22%7D&extensions=%7B%22persistedQuery%22%3A%7B%22version%22%3A1%2C%22sha256Hash%22%3A%225a17a9af1830b58b94a912995b7947b24f27f1301c6ea8ab71a9eb1a6a86585b%22%7D%7D')[0])
+    info = extract(parse('https://api.500px.com/graphql?operationName=ProfileRendererQuery&variables=%7B%22username%22%3A%22the-maksimov%22%7D&extensions=%7B%22persistedQuery%22%3A%7B%22version%22%3A1%2C%22sha256Hash%22%3A%22105058632482dd2786fd5775745908dc928f537b28e28356b076522757d65c19%22%7D%7D')[0])
 
     assert info.get('uid') == 'dXJpOm5vZGU6VXNlcjoyMzg5Ng=='
     assert info.get('legacy_id') == '23896'
@@ -289,6 +366,13 @@ def test_soundcloud():
     assert info.get('uid') == '78365'
     assert info.get('username') == 'danielpatterson'
     assert info.get('name') == 'Daniel Patterson'
+    assert info.get('following_count') == '23'
+    assert info.get('follower_count') == '36'
+    assert info.get('is_verified') == 'False'
+    assert info.get('image') == 'https://i1.sndcdn.com/avatars-000222811304-x9f1ao-large.jpg'
+    assert info.get('location') == 'Baton Rouge'
+    assert info.get('country_code') == 'US'
+    assert info.get('created_at') == '2009-02-27T16:08:17Z'
 
 
 def test_vcru():
@@ -328,7 +412,7 @@ def test_youtube():
 def test_google_maps():
     info = extract(parse('https://www.google.com/maps/contrib/117503292148966883754')[0])
 
-    assert info.get('contribution_level') == 'Level 3 Local Guide | 132 Points'
+    assert info.get('contribution_level').startswith('Level 3 Local Guide')
     assert info.get('name') == 'Art NI'
 
 
@@ -463,12 +547,13 @@ def test_yandex_collections_api():
 
 
 def test_tiktok():
-    info = extract(parse('https://www.tiktok.com/@red')[0])
+    headers = {'user-agent': 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_6) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/87.0.4280.141 Safari/537.36'}
+    info = extract(parse('https://www.tiktok.com/@red', headers=headers)[0])
 
     assert info.get('tiktok_id') == '6667977707978850310'
     assert info.get('tiktok_username') == 'red'
     assert info.get('fullname') == '(RED)'
-    assert info.get('bio') == 'Whether AIDS or COVID-19, we can’t beat pandemics without strong health systems.'
+    assert 'bio' in info
     assert 'tiktokcdn.com' in info.get('image')
     assert info.get('is_verified') == 'True'
     assert info.get('is_secret') == 'False'
